.. _legacy-schema:

Legacy schemas
==============

The following legacy schemas are not part of the most recent ASDF core schemas:

.. asdf-autoschemas::

   core/asdf-1.0.0
   core/column-1.0.0
   core/integer-1.0.0
   core/ndarray-1.0.0
   core/subclass_metadata-1.0.0
   core/table-1.0.0
   fits/fits-1.0.0
   time/time-1.0.0
   time/time-1.1.0
   unit/quantity-1.1.0
   asdf-schema-1.1.0
